package idsearcher
import "github.com/spdx/tools-golang/idsearcher"
Package idsearcher is used to search for short-form IDs in files within a directory, and to build an SPDX Document containing those license findings. SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later
Index ¶
- func BuildIDsDocument(packageName string, dirRoot string, idconfig *Config) (*spdx.Document, error)
- type Config
Functions ¶
func BuildIDsDocument ¶
BuildIDsDocument creates an SPDX Document and searches for short-form IDs in each file, filling in license fields as appropriate. It returns that document or error if any is encountered. Arguments:
- packageName: name of package / directory
- dirRoot: path to directory to be analyzed
- namespacePrefix: URI representing a prefix for the namespace with which the SPDX Document will be associated
Types ¶
type Config ¶
type Config struct {
// NamespacePrefix should be a URI representing a prefix for the
// namespace with which the SPDX Document will be associated.
// It will be used in the DocumentNamespace field in the CreationInfo
// section, followed by the per-Document package name and a random UUID.
NamespacePrefix string
// BuilderPathsIgnored lists certain paths to be omitted from the built
// document. Each string should be a path, relative to the package's
// dirRoot, to a specific file or (for all files in a directory) ending
// in a slash. Prefix the string with "**" to omit all instances of that
// file / directory, regardless of where it is in the file tree.
BuilderPathsIgnored []string
// SearcherPathsIgnored lists certain paths that should not be searched
// by idsearcher, even if those paths have Files present. It uses the
// same format as BuilderPathsIgnored.
SearcherPathsIgnored []string
}
Config is a collection of configuration settings for docbuilder. A few mandatory fields are set here so that they can be repeatedly reused in multiple calls to Build.
Source Files ¶
- Version
- v0.5.5 (latest)
- Published
- Jun 17, 2024
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 9 months ago –
Tools for package owners.